from django.conf import settings
from django.db import models

from djangoldp.models import Model

class Skill(Model):
    name = models.CharField(max_length=255, default='')
    users = models.ManyToManyField(settings.AUTH_USER_MODEL, blank=True, related_name="skills")

    class Meta:
        permission_classes=[]
        serializer_fields=["@id", "name"]
        nested_fields=[]
        container_path = 'skills/'
        rdf_type = 'hd:skill'


    def __str__(self):
        return self.name



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-04-25 09:33
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_skill', '0002_auto_20190116_0919'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='skill',
            options={},
        ),
    ]
